@@ -72,7 +72,7 @@ of 'Error'.
 """
 _DOC_ERRORS = ["enchnt", "enchnt", "incant", "fr"]
 
-__version__ = "3.2.0"
+__version__ = "3.2.2"
 
 import os
 import warnings
@@ -158,12 +158,12 @@ class _EnchantObject:
     def _raise_error(self, default="Unspecified Error", eclass=Error):
         """Raise an exception based on available error messages.
 
-         This method causes an Error to be raised.  Subclasses should
-         override it to retrieve an error indication from the underlying
-         API if possible.  If such a message cannot be retrieved, the
-         argument value <default> is used.  The class of the exception
-         can be specified using the argument <eclass>
-         """
+        This method causes an Error to be raised.  Subclasses should
+        override it to retrieve an error indication from the underlying
+        API if possible.  If such a message cannot be retrieved, the
+        argument value <default> is used.  The class of the exception
+        can be specified using the argument <eclass>
+        """
         raise eclass(default)
 
     _raise_error._DOC_ERRORS = ["eclass"]
@@ -554,7 +554,7 @@ class Dict(_EnchantObject):
         # Calling free() might fail if python is shutting down
         try:
             self._free()
-        except AttributeError:
+        except (AttributeError, TypeError):
             pass
 
     def _switch_this(self, this, broker):
